import { __decorate } from "tslib";
import { attr, observable } from '@microsoft/fast-element';
import { FoundationElement } from '@microsoft/fast-foundation';
import { classNames } from '@microsoft/fast-web-utilities';
import { foundationActionsMenuStyles as styles } from './actions-menu.styles';
import { foundationActionsMenuTemplate as template } from './actions-menu.template';
export class ActionsMenu extends FoundationElement {
    constructor() {
        super(...arguments);
        this.isVertical = false;
        this.addDefaultActions = true;
        this.autoCloseOnAction = true;
        this.name = 'Actions';
        this.open = false;
    }
    definitionChanged(oldValue, newValue) {
        var _a, _b;
        this.actions = [...((_a = this.actions) !== null && _a !== void 0 ? _a : []), ...((_b = newValue === null || newValue === void 0 ? void 0 : newValue.actions) !== null && _b !== void 0 ? _b : [])];
        delete this.definition.actions;
        if (newValue.buttonText) {
            this.name = newValue.buttonText;
            delete this.definition.customButtonText;
        }
        if (newValue.isVertical) {
            this.isVertical = newValue.isVertical;
            delete this.definition.isVertical;
        }
        if (newValue.buttonAppearance) {
            this.buttonAppearance = newValue.buttonAppearance;
            delete this.definition.buttonAppearance;
        }
    }
    openChanged() {
        this.classNames = classNames(['visible', this.open], ['hidden', !this.open]);
    }
    toggleActionsMenuVisibility() {
        this.open = !this.open;
    }
    onActionMenuItemClick(callback) {
        if (this.autoCloseOnAction)
            this.open = false;
        callback(this.rowData);
    }
    get allActions() {
        var _a;
        const defaultActions = [
            {
                name: '✖',
                callback: () => (this.open = false),
            },
        ];
        return this.addDefaultActions ? [...((_a = this.actions) !== null && _a !== void 0 ? _a : []), ...defaultActions] : this.actions;
    }
    get rowData() {
        if (!this.definition)
            return;
        const { node, data } = this.definition;
        return (node === null || node === void 0 ? void 0 : node.data) || data;
    }
}
__decorate([
    observable
], ActionsMenu.prototype, "actions", void 0);
__decorate([
    attr({ attribute: 'is-vertical', mode: 'boolean' })
], ActionsMenu.prototype, "isVertical", void 0);
__decorate([
    attr({ attribute: 'add-default-actions', mode: 'boolean' })
], ActionsMenu.prototype, "addDefaultActions", void 0);
__decorate([
    attr({ attribute: 'auto-close-on-action', mode: 'boolean' })
], ActionsMenu.prototype, "autoCloseOnAction", void 0);
__decorate([
    observable
], ActionsMenu.prototype, "classNames", void 0);
__decorate([
    observable
], ActionsMenu.prototype, "definition", void 0);
__decorate([
    attr
], ActionsMenu.prototype, "name", void 0);
__decorate([
    attr({ attribute: 'open', mode: 'boolean' })
], ActionsMenu.prototype, "open", void 0);
__decorate([
    attr
], ActionsMenu.prototype, "buttonAppearance", void 0);
export const foundationActionsMenu = ActionsMenu.compose({
    baseName: 'actions-menu',
    styles,
    template,
});
//# sourceMappingURL=actions-menu.js.map