import { __decorate } from "tslib";
import { FoundationElement } from '@microsoft/fast-foundation';
import { attr, observable } from '@microsoft/fast-element';
import { classNames } from '@microsoft/fast-web-utilities';
import dayjs from 'dayjs';
import { foundationDatePickerStyles as styles } from './date-picker.styles';
import { foundationDatePickerTemplate as template } from './date-picker.template';
import Calendar from './calendar';
import Day from './day';
export const foundationDatePickerShadowOptions = undefined;
export const defaultDatePickerConfig = {};
export class DatePicker extends FoundationElement {
    formatChanged(oldValue, newValue) {
        if (newValue && this.calendar) {
            this.formatDate = dayjs(this.currentDate.Date).format(newValue);
        }
    }
    valueChanged(oldValue, newValue) {
        if (newValue && this.calendar) {
            this.currentDate = new Day(new Date(newValue));
            this.calendar.goToDate(this.currentDate.monthNumber, this.currentDate.year);
            this.formatDate = dayjs(this.currentDate.Date).format(this.format);
            this.updateHeaderText();
            this.monthList = this.getMonthDaysGrid();
        }
    }
    constructor() {
        var _a;
        super();
        this.format = 'MM-DD-YYYY';
        this.visible = false;
        this.position = 'bottom';
        const lang = 'en-US';
        const date = new Date((_a = this.currentDate) !== null && _a !== void 0 ? _a : (this.getAttribute('value') || Date.now()));
        this.substringNumber = 3;
        this.currentDate = new Day(date, lang);
        this.value = dayjs(this.currentDate.Date).format('MM-DD-YYYY');
        this.calendar = new Calendar(this.currentDate.year, this.currentDate.monthNumber, lang);
    }
    connectedCallback() {
        super.connectedCallback();
        this.currentMonth = this.calendar.month.name;
        this.currentYear = this.calendar.year;
        this.formatDate = dayjs(this.currentDate.Date).format(this.format);
        this.toggleButton.addEventListener('click', () => this.toggleCalendar());
        this.prevBtn.addEventListener('click', () => this.prevMonth());
        this.nextBtn.addEventListener('click', () => this.nextMonth());
        this.monthList = this.getMonthDaysGrid();
    }
    updateHeaderText() {
        this.currentMonth = this.calendar.month.name;
        this.currentYear = this.calendar.year;
    }
    toggleCalendar() {
        this.visible = !this.visible;
        this.toggleVisibility();
        if (!this.isCurrentCalendarMonth()) {
            this.calendar.goToDate(this.currentDate.monthNumber, this.currentDate.year);
            this.updateHeaderText();
        }
    }
    toggleVisibility() {
        this.calendarDropdownClasses = classNames(['visible', this.visible], this.position);
    }
    isSelectedDate(date) {
        return dayjs(date.Date).isSame(this.currentDate.Date, 'day');
    }
    isCurrentCalendarMonth() {
        return (this.currentMonth === this.currentDate.monthNumber &&
            this.currentYear === this.currentDate.year);
    }
    prevMonth() {
        this.calendar.goToPreviousMonth();
        this.updateHeaderText();
        this.monthList = this.getMonthDaysGrid();
    }
    nextMonth() {
        this.calendar.goToNextMonth();
        this.updateHeaderText();
        this.monthList = this.getMonthDaysGrid();
    }
    selectDay(day) {
        if (dayjs(day.Date).isSame(this.currentDate.Date))
            return;
        this.currentDate = day;
        if (day.monthNumber !== this.calendar.month.number) {
            this.prevMonth();
        }
        this.formatDate = dayjs(this.currentDate.Date).format(this.format);
        this.value = dayjs(day.Date).format('MM-DD-YYYY');
        this.toggleCalendar();
    }
    getMonthDaysGrid() {
        const firstDayOfTheMonth = this.calendar.month.getDay(1);
        const prevMonth = this.calendar.getPreviousMonth();
        const totalLastMonthFinalDays = firstDayOfTheMonth.dayNumber - 1;
        const totalDays = this.calendar.month.numberOfDays + totalLastMonthFinalDays;
        const monthList = Array.from({ length: totalDays });
        for (let i = totalLastMonthFinalDays; i < totalDays; i += 1) {
            monthList[i] = this.calendar.month.getDay(i + 1 - totalLastMonthFinalDays);
        }
        for (let i = 0; i < totalLastMonthFinalDays; i += 1) {
            const inverted = totalLastMonthFinalDays - (i + 1);
            monthList[i] = prevMonth.getDay(prevMonth.numberOfDays - inverted);
        }
        return monthList;
    }
}
__decorate([
    attr
], DatePicker.prototype, "format", void 0);
__decorate([
    attr
], DatePicker.prototype, "visible", void 0);
__decorate([
    attr
], DatePicker.prototype, "position", void 0);
__decorate([
    attr
], DatePicker.prototype, "value", void 0);
__decorate([
    observable
], DatePicker.prototype, "currentDate", void 0);
__decorate([
    observable
], DatePicker.prototype, "currentMonth", void 0);
__decorate([
    observable
], DatePicker.prototype, "currentYear", void 0);
__decorate([
    observable
], DatePicker.prototype, "calendarDropdownClasses", void 0);
__decorate([
    observable
], DatePicker.prototype, "formatDate", void 0);
__decorate([
    observable
], DatePicker.prototype, "monthList", void 0);
export const foundationDatePicker = DatePicker.compose(Object.assign({ baseName: 'date-picker', styles,
    template, shadowOptions: foundationDatePickerShadowOptions }, defaultDatePickerConfig));
//# sourceMappingURL=date-picker.js.map